==> potion_0.0.3.tar.gz: potion-0.0.3/src/main.c <==

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdlib.h>
#include <event.h>

#include <debug/log.h>
#include <debug/memory.h>

#include "gui.h"
#include "link.h"

int main (int argc,char *argv[])
{
   const struct config *config;

   mem_open (NULL);
   log_open (NULL,LOG_NORMAL,LOG_HAVE_COLORS);
   atexit (log_close);
   atexit (mem_close);

   config = config_parse (argc,argv);
   atexit (config_destroy);

   log_close ();
   log_open (config->syslog,LOG_NORMAL,LOG_DEBUG_PREFIX_ONLY);

   link_register (&link_ether);
   link_register (&link_sll);

   event_init ();

   if (gui_open (config))
	 exit (EXIT_FAILURE);

   atexit (gui_close);

   exit (event_dispatch () ? EXIT_FAILURE : EXIT_SUCCESS);
}

==> potion_0.0.4.tar.gz: potion-0.0.4/src/main.c <==

/*
 * Copyright (c) Abraham vd Merwe <abz@blio.com>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *	  notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *	  notice, this list of conditions and the following disclaimer in the
 *	  documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the author nor the names of other contributors
 *	  may be used to endorse or promote products derived from this software
 *	  without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdlib.h>
#include <event.h>

#include <debug/log.h>
#include <debug/memory.h>

#include "gui.h"
#include "link.h"

int main (int argc,char *argv[])
{
   const struct config *config;

   mem_open (NULL);
   log_open (NULL,LOG_NORMAL,LOG_HAVE_COLORS);
   atexit (log_close);
   atexit (mem_close);

   config = config_parse (argc,argv);
   atexit (config_destroy);

   log_close ();
   log_open (config->syslog,LOG_NORMAL,LOG_DEBUG_PREFIX_ONLY);

   link_register (&link_ether);
   link_register (&link_sll);

   event_init ();

   if (gui_open (config))
	 exit (EXIT_FAILURE);

   atexit (gui_close);

   if (event_dispatch ())
	 {
		log_printf (LOG_ERROR,"event error: %m\n");
		exit (EXIT_FAILURE);
	 }

   exit (EXIT_SUCCESS);
}
